==> gcc-g++-4.3.6.tar.gz: gcc-4.3.6/libstdc++-v3/testsuite/ext/pb_ds/regression/trie_no_data_map_rand.cc <==
// { dg-options "-DPB_DS_REGRESSION" }
// -*- C++ -*-

// Copyright (C) 2005, 2006 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the terms
// of the GNU General Public License as published by the Free Software
// Foundation; either version 2, or (at your option) any later
// version.

// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this library; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// As a special exception, you may use this file as part of a free
// software library without restriction.  Specifically, if other files
// instantiate templates or use macros or inline functions from this
// file, or you compile this file and link it with other files to
// produce an executable, this file does not by itself cause the
// resulting executable to be covered by the GNU General Public
// License.  This exception does not however invalidate any other
// reasons why the executable file might be covered by the GNU General
// Public License.

// Copyright (C) 2004 Ami Tavory and Vladimir Dreizin, IBM-HRL.

// Permission to use, copy, modify, sell, and distribute this software
// is hereby granted without fee, provided that the above copyright
// notice appears in all copies, and that both that copyright notice
// and this permission notice appear in supporting documentation. None
// of the above authors, nor IBM Haifa Research Laboratories, make any
// representation about the suitability of this software for any
// purpose. It is provided "as is" without express or implied
// warranty.

/**
 * @file trie_no_data_map_rand_regression_test.cpp
 * Contains a random-operation test for maps and sets.
 */

// { dg-require-time "" }

#include <regression/rand/assoc/rand_regression_test.hpp>
#include <regression/assoc/common_type.hpp>

// This can take long on simulators, timing out the test.
// { dg-options "-DPB_DS_REGRESSION -DITERATIONS=5" { target simulator } }
#ifndef ITERATIONS
#define ITERATIONS 5000
#endif
#ifndef KEYS
#define KEYS 10000
#endif
int
main(int argc, char* a_p_argv[])
{
  using namespace __gnu_pbds::test;
  typedef trie_set_tl_t map_tl_t;

  return rand_regression_test(ITERATIONS, KEYS,
			      "trie_no_data_map_rand_regression_test", 
			      map_tl_t());
}

==> gcc-g++-4.5.4.tar.gz: gcc-4.5.4/libstdc++-v3/testsuite/ext/pb_ds/regression/trie_no_data_map_rand.cc <==
// { dg-options "-DPB_DS_REGRESSION" }
// -*- C++ -*-

// Copyright (C) 2005, 2006, 2009 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the terms
// of the GNU General Public License as published by the Free Software
// Foundation; either version 3, or (at your option) any later
// version.

// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.


// Copyright (C) 2004 Ami Tavory and Vladimir Dreizin, IBM-HRL.

// Permission to use, copy, modify, sell, and distribute this software
// is hereby granted without fee, provided that the above copyright
// notice appears in all copies, and that both that copyright notice
// and this permission notice appear in supporting documentation. None
// of the above authors, nor IBM Haifa Research Laboratories, make any
// representation about the suitability of this software for any
// purpose. It is provided "as is" without express or implied
// warranty.

/**
 * @file trie_no_data_map_rand_regression_test.cpp
 * Contains a random-operation test for maps and sets.
 */

// { dg-require-time "" }

#include <regression/rand/assoc/rand_regression_test.hpp>
#include <regression/common_type.hpp>

// This can take long on simulators, timing out the test.
// { dg-options "-DPB_DS_REGRESSION -DITERATIONS=5" { target simulator } }
// { dg-timeout-factor 2.0 }
#ifndef ITERATIONS
#define ITERATIONS 5000
#endif
#ifndef KEYS
#define KEYS 10000
#endif
int
main(int argc, char* a_p_argv[])
{
  using namespace __gnu_pbds::test;
  typedef trie_set_tl_t map_tl_t;

  return rand_regression_test(ITERATIONS, KEYS,
			      "trie_no_data_map_rand_regression_test", 
			      map_tl_t());
}
